@@ -8,6 +8,7 @@
 /* -------------------------------------------------- */
 
 #include "Model_TX.h"
+#include "models_tx.h"
 
 
 /* Model_TX Constructor */
@@ -65,7 +66,7 @@ double Model_TX::approx_dt(double* phi, double dt_scale) const {
       uu = unif_L() >= 0.5 ? 1.0 : -1.0;
 
       /* calculate accumulated evidence */
-      xx += dt_*vv + sqrtdt*DD*uu;
+      xx += dt_sims*vv + sqrtdt*DD*uu;
 
       /* check if accumulated evidence has crossed a decision threshold */
       if ((xx >= bu) || (xx <= bl)) {
@@ -1299,3 +1300,5 @@ int Model_TX::grid_pdf(double *Rrt, double *Rpdf_u, double *Rpdf_l, double *phi)
   return 0;
 
 }
+
+ModelTX_Callbacks CSTM_TX::callbacks;
